@@ -8,6 +8,7 @@ from pymchelper.writers.sparse import SparseWriter
 from pymchelper.writers.trip98cube import TRiP98CubeWriter
 from pymchelper.writers.trip98ddd import TRiP98DDDWriter
 from pymchelper.writers.hdf import HdfWriter
+from pymchelper.writers.json import JsonWriter
 
 
 class Converters(IntEnum):
@@ -23,6 +24,7 @@ class Converters(IntEnum):
     sparse = 7
     inspect = 8
     hdf = 9
+    json = 10
 
     @classmethod
     def _converter_mapping(cls, item):
@@ -35,7 +37,8 @@ class Converters(IntEnum):
             cls.excel: ExcelWriter,
             cls.sparse: SparseWriter,
             cls.inspect: Inspector,
-            cls.hdf: HdfWriter
+            cls.hdf: HdfWriter,
+            cls.json: JsonWriter
         }.get(item)
 
     @classmethod
